<?php

namespace Drupal\registration_validation\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\ConfigFormBase;

/**
 * Configure file system settings for this site.
 */
class RegistrationValidationSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'registration_validation_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['registration.validation'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['blacklist_domains'] = array(
      '#type' => 'fieldset',
      '#title' => t('Blacklist e-mail domains'),
      '#description' => t('Often times you will find specific domains getting past CAPTCHA modules, if they are installed. When attempting to register with any e-mail domains you enter below, the registration will be blocked and a message will appear informing the user to use a different e-mail address.'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    );
    $form['blacklist_domains']['domains'] = array(
      '#type' => 'textarea',
      '#title' => t('Blacklisted e-mail domains'),
      '#description' => t('Specify blacklisted e-mail domains by using their domain name and top-level domain (.com, .org, .info, etc.). Enter one domain per line. Example domains are <em class="placeholder">example.com</em> for <em class="placeholder">@example.com</em> e-mail addresses and <em class="placeholder">example.*</em> for all <em class="placeholder">@example.*</em> e-mail addresses (.com, .org, .info, etc.).'),
      '#default_value' => \Drupal::config('registration_validation.settings')->get('domains'),
    );
    $form['blacklist_domains']['domains_message'] = array(
      '#type' => 'textarea',
      '#title' => t('Failed validation error message'),
      '#description' => t('Enter the message to display on the page if the user\'s e-mail address domain is blacklisted. You can enter "%domain" (without quotes) anywhere in the message to print the domain name.<br>Default message: <em class="placeholder">The e-mail domain %domain has been blacklisted from registering. Please enter a different e-mail address.</em>'),
      '#default_value' => \Drupal::config('registration_validation.settings')->get('domains_message'),
    );
    $form['blacklist_usernames'] = array(
      '#type' => 'fieldset',
      '#title' => t('Blacklist usernames'),
      '#description' => t('When attempting to register a username with any strings you enter below, the registration will be blocked and a message will appear informing the user to use a different username.'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    );
    $form['blacklist_usernames']['usernames'] = array(
      '#type' => 'textarea',
      '#title' => t('Blacklisted username strings'),
      '#description' => t('Specify blacklisted strings in usernames. Enter one domain per line. Example strings are <em class="placeholder">example</em> for example as the complete username and <em class="placeholder">*example*</em> for example appearing anywhere in the username.'),
      '#default_value' => \Drupal::config('registration_validation.settings')->get('usernames'),
    );
    $form['blacklist_usernames']['usernames_message'] = array(
      '#type' => 'textarea',
      '#title' => t('Failed validation error message'),
      '#description' => t('Enter the message to display on the page if the username is blacklisted or contains a blacklisted string. You can enter "%username" (without quotes) anywhere in the message to print the username or string.<br>Default message: <em class="placeholder">The username contains %username, which has been blacklisted from being used when registering. Please enter a different username.</em>'),
      '#default_value' => \Drupal::config('registration_validation.settings')->get('usernames_message'),
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = \Drupal::configFactory()->getEditable('registration_validation.settings')
      ->set('domains', $form_state->getValue('domains'))
      ->set('domains_message', $form_state->getValue('domains_message'))
      ->set('usernames', $form_state->getValue('usernames'))
      ->set('usernames_message', $form_state->getValue('usernames_message'));
    $config->save();

    parent::submitForm($form, $form_state);
  }
}
